@@ -35,10 +35,10 @@
 #include <glib/gi18n.h>
 
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 #include <libnotify/notify.h>
 #include <packagekit-glib2/packagekit.h>
 #include <canberra-gtk.h>
+#include <gio/gio.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -72,12 +72,12 @@ struct GpkCheckUpdatePrivate
 	gboolean		 icon_inhibit_update_in_progress;
 	gboolean		 icon_inhibit_network_offline;
 	gboolean		 icon_inhibit_update_viewer_connected;
-	gchar			*icon_name;
+	GIcon			*gicon;
 	PkTransactionList	*tlist;
 	PkControl		*control;
 	GpkAutoRefresh		*arefresh;
 	PkTask			*task;
-	GConfClient		*gconf_client;
+	GSettings		*settings;
 	guint			 number_updates_critical_last_shown;
 	NotifyNotification	*notification_updates_available;
 	NotifyNotification	*notification_error;
@@ -85,6 +85,7 @@ struct GpkCheckUpdatePrivate
 	guint			 updates_changed_id;
 	GCancellable		*cancellable;
 	PkError			*error_code;
+	GVolumeMonitor		*volume_monitor;
 };
 
 G_DEFINE_TYPE (GpkCheckUpdate, gpk_check_update, G_TYPE_OBJECT)
@@ -98,7 +99,7 @@ gpk_check_update_set_icon_visibility (GpkCheckUpdate *cupdate)
 	gboolean ret = FALSE;
 
 	/* check we have data */
-	if (cupdate->priv->icon_name == NULL) {
+	if (cupdate->priv->gicon == NULL) {
 		egg_debug ("not showing icon as nothing to show");
 		goto out;
 	}
@@ -122,7 +123,7 @@ gpk_check_update_set_icon_visibility (GpkCheckUpdate *cupdate)
 out:
 	/* show or hide icon */
 	if (ret) {
-		gtk_status_icon_set_from_icon_name (cupdate->priv->status_icon, cupdate->priv->icon_name);
+		gtk_status_icon_set_from_gicon (cupdate->priv->status_icon, cupdate->priv->gicon);
 		gtk_status_icon_set_visible (cupdate->priv->status_icon, TRUE);
 	} else {
 		gtk_status_icon_set_visible (cupdate->priv->status_icon, FALSE);
@@ -131,13 +132,14 @@ out:
 }
 
 /**
- * gpk_check_update_set_icon_name:
+ * gpk_check_update_set_gicon:
  **/
 static void
-gpk_check_update_set_icon_name (GpkCheckUpdate *cupdate, const gchar *icon_name)
+gpk_check_update_set_gicon (GpkCheckUpdate *cupdate, GIcon *gicon)
 {
-	g_free (cupdate->priv->icon_name);
-	cupdate->priv->icon_name = g_strdup (icon_name);
+	if (cupdate->priv->gicon != NULL)
+		g_object_unref (cupdate->priv->gicon);
+	cupdate->priv->gicon = g_object_ref (gicon);
 	gpk_check_update_set_icon_visibility (cupdate);
 }
 
@@ -381,9 +383,9 @@ gpk_check_update_finished_notify (GpkCheckUpdate *cupdate, PkResults *results)
 		g_string_set_size (message_text, message_text->len-1);
 
 	/* do we do the notification? */
-	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_COMPLETE, NULL);
+	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE);
 	if (!ret) {
-		egg_debug ("ignoring due to GConf");
+		egg_debug ("ignoring due to GSettings");
 		goto out;
 	}
 
@@ -488,6 +490,7 @@ gpk_check_update_update_system_finished_cb (PkTask *task, GAsyncResult *res, Gpk
 	PkResults *results;
 	GError *error = NULL;
 	PkError *error_code = NULL;
+	guint timer_id;
 
 	/* get the results */
 	results = pk_task_generic_finish (task, res, &error);
@@ -496,8 +499,12 @@ gpk_check_update_update_system_finished_cb (PkTask *task, GAsyncResult *res, Gpk
 		g_error_free (error);
 
 		/* we failed, so re-get the update list */
-		gpk_check_update_set_icon_name (cupdate, NULL);
-		g_timeout_add_seconds (GPK_CHECK_UPDATE_FAILED_TASK_RECHECK_DELAY, (GSourceFunc) gpk_check_update_get_updates_post_update_cb, cupdate);
+		gpk_check_update_set_gicon (cupdate, NULL);
+		timer_id = g_timeout_add_seconds (GPK_CHECK_UPDATE_FAILED_TASK_RECHECK_DELAY,
+						  (GSourceFunc) gpk_check_update_get_updates_post_update_cb, cupdate);
+#if GLIB_CHECK_VERSION(2,25,8)
+		g_source_set_name_by_id (timer_id, "[GpkCheckUpdate] failed");
+#endif
 		goto out;
 	}
 
@@ -562,23 +569,23 @@ gpk_check_update_libnotify_cb (NotifyNotification *notification, gchar *action,
 	GpkCheckUpdate *cupdate = GPK_CHECK_UPDATE (data);
 
 	if (g_strcmp0 (action, "do-not-show-complete-restart") == 0) {
-		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_UPDATE_COMPLETE_RESTART);
-		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_COMPLETE_RESTART, FALSE, NULL);
+		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE_RESTART);
+		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE_RESTART, FALSE);
 	} else if (g_strcmp0 (action, "do-not-show-complete") == 0) {
-		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_UPDATE_COMPLETE);
-		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_COMPLETE, FALSE, NULL);
+		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE);
+		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE, FALSE);
 	} else if (g_strcmp0 (action, "do-not-show-update-started") == 0) {
-		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_UPDATE_STARTED);
-		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_STARTED, FALSE, NULL);
+		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_UPDATE_STARTED);
+		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_STARTED, FALSE);
 	} else if (g_strcmp0 (action, "do-not-show-notify-critical") == 0) {
-		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_CRITICAL);
-		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_CRITICAL, FALSE, NULL);
+		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_CRITICAL);
+		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_CRITICAL, FALSE);
 	} else if (g_strcmp0 (action, "do-not-show-update-not-battery") == 0) {
-		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_UPDATE_NOT_BATTERY);
-		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_NOT_BATTERY, FALSE, NULL);
+		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_UPDATE_NOT_BATTERY);
+		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_NOT_BATTERY, FALSE);
 	} else if (g_strcmp0 (action, "distro-upgrade-do-not-show-available") == 0) {
-		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_DISTRO_UPGRADES);
-		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_DISTRO_UPGRADES, FALSE, NULL);
+		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_DISTRO_UPGRADES);
+		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_DISTRO_UPGRADES, FALSE);
 	} else if (g_strcmp0 (action, "show-error-details") == 0) {
 		title = gpk_error_enum_to_localised_text (pk_error_get_code (cupdate->priv->error_code));
 		message = gpk_error_enum_to_localised_message (pk_error_get_code (cupdate->priv->error_code));
@@ -623,9 +630,9 @@ gpk_check_update_critical_updates_warning (GpkCheckUpdate *cupdate, GPtrArray *a
 	g_return_if_fail (GPK_IS_CHECK_UPDATE (cupdate));
 
 	/* do we do the notification? */
-	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_CRITICAL, NULL);
+	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_CRITICAL);
 	if (!ret) {
-		egg_debug ("ignoring due to GConf");
+		egg_debug ("ignoring due to GSettings");
 		return;
 	}
 
@@ -674,74 +681,40 @@ gpk_check_update_critical_updates_warning (GpkCheckUpdate *cupdate, GPtrArray *a
 }
 
 /**
- * gpk_check_update_client_info_to_bitfield:
+ * gpk_check_update_get_status_icon:
  **/
-static PkBitfield
-gpk_check_update_client_info_to_bitfield (GpkCheckUpdate *cupdate, GPtrArray *array)
+static GIcon *
+gpk_check_update_get_status_icon (GpkCheckUpdate *cupdate, GPtrArray *array)
 {
 	guint i;
-	PkBitfield infos = 0;
-	PkPackage *item;
-	gchar **split;
+	PkPackage *package;
 	PkInfoEnum info;
-	gchar *package_id = NULL;
+	GIcon *icon = NULL;
 
-	g_return_val_if_fail (GPK_IS_CHECK_UPDATE (cupdate), PK_INFO_ENUM_UNKNOWN);
-
-	/* shortcut */
-	if (array->len == 0)
-		return PK_INFO_ENUM_UNKNOWN;
-
-	/* add each status to a array */
-	for (i=0; i<array->len; i++) {
-		item = g_ptr_array_index (array, i);
-		g_object_get (item,
-			      "info", &info,
-			      "package-id", &package_id,
-			      NULL);
-		split = pk_package_id_split (package_id);
-		egg_debug ("%s %s", split[PK_PACKAGE_ID_NAME], pk_info_enum_to_text (info));
-		g_strfreev (split);
-		pk_bitfield_add (infos, info);
-		g_free (package_id);
-	}
-	return infos;
-}
-
-/**
- * gpk_check_update_get_best_update_icon:
- **/
-static const gchar *
-gpk_check_update_get_best_update_icon (GpkCheckUpdate *cupdate, GPtrArray *array)
-{
-	gint value;
-	PkBitfield infos;
-	const gchar *icon;
-
-	g_return_val_if_fail (GPK_IS_CHECK_UPDATE (cupdate), NULL);
-
-	/* get an enumerated array with all the update types */
-	infos = gpk_check_update_client_info_to_bitfield (cupdate, array);
-
-	/* get the most important icon */
-	value = pk_bitfield_contain_priority (infos,
-					      PK_INFO_ENUM_SECURITY,
-					      PK_INFO_ENUM_IMPORTANT,
-					      PK_INFO_ENUM_BUGFIX,
-					      PK_INFO_ENUM_NORMAL,
-					      PK_INFO_ENUM_ENHANCEMENT,
-					      PK_INFO_ENUM_LOW,
-					      PK_INFO_ENUM_BLOCKED, -1);
-	if (value == -1) {
-		egg_warning ("should not be possible!");
-		value = PK_INFO_ENUM_LOW;
-	} else if (value == PK_INFO_ENUM_BLOCKED) {
-		/* all updates are blocked */
-		return NULL;
+	/* look for any urgent updates */
+	for (i = 0; i< array->len; i++) {
+		package = g_ptr_array_index (array, i);
+		info = pk_package_get_info (package);
+		if (info == PK_INFO_ENUM_SECURITY ||
+		    info == PK_INFO_ENUM_IMPORTANT) {
+			icon = g_themed_icon_new_with_default_fallbacks ("software-update-urgent-symbolic");
+			goto out;
+		}
 	}
 
-	/* get the icon */
-	icon = gpk_info_enum_to_icon_name (value);
+	/* look for any normal updates */
+	for (i = 0; i< array->len; i++) {
+		package = g_ptr_array_index (array, i);
+		info = pk_package_get_info (package);
+		if (info == PK_INFO_ENUM_BUGFIX ||
+		    info == PK_INFO_ENUM_NORMAL ||
+		    info == PK_INFO_ENUM_ENHANCEMENT ||
+		    info == PK_INFO_ENUM_LOW) {
+			icon = g_themed_icon_new_with_default_fallbacks ("software-update-available-symbolic");
+			goto out;
+		}
+	}
+out:
 	return icon;
 }
 
@@ -758,7 +731,7 @@ gpk_check_update_check_on_battery (GpkCheckUpdate *cupdate)
 
 	g_return_val_if_fail (GPK_IS_CHECK_UPDATE (cupdate), FALSE);
 
-	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_UPDATE_BATTERY, NULL);
+	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_UPDATE_BATTERY);
 	if (ret) {
 		egg_debug ("okay to update due to policy");
 		return TRUE;
@@ -771,9 +744,9 @@ gpk_check_update_check_on_battery (GpkCheckUpdate *cupdate)
 	}
 
 	/* do we do the notification? */
-	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_NOT_BATTERY, NULL);
+	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_NOT_BATTERY);
 	if (!ret) {
-		egg_debug ("ignoring due to GConf");
+		egg_debug ("ignoring due to GSettings");
 		return FALSE;
 	}
 
@@ -811,9 +784,9 @@ gpk_check_update_get_update_policy (GpkCheckUpdate *cupdate)
 
 	g_return_val_if_fail (GPK_IS_CHECK_UPDATE (cupdate), FALSE);
 
-	updates = gconf_client_get_string (cupdate->priv->gconf_client, GPK_CONF_AUTO_UPDATE, NULL);
+	updates = g_settings_get_string (cupdate->priv->settings, GPK_SETTINGS_AUTO_UPDATE);
 	if (updates == NULL) {
-		egg_warning ("'%s' gconf key is null!", GPK_CONF_AUTO_UPDATE);
+		egg_warning ("'%s' settings key is null!", GPK_SETTINGS_AUTO_UPDATE);
 		return GPK_UPDATE_ENUM_UNKNOWN;
 	}
 	update = gpk_update_enum_from_text (updates);
@@ -831,8 +804,8 @@ gpk_check_update_notify_doing_updates (GpkCheckUpdate *cupdate)
 	GError *error = NULL;
 	NotifyNotification *notification;
 
-	/* in GConf? */
-	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_CRITICAL, NULL);
+	/* in GSettings? */
+	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_CRITICAL);
 	if (!ret)
 		goto out;
 
@@ -873,7 +846,7 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	GString *status_tooltip = NULL;
 	GpkUpdateEnum update;
 	GPtrArray *security_array = NULL;
-	const gchar *icon;
+	GIcon *icon = NULL;
 	gchar **package_ids;
 	GPtrArray *array = NULL;
 	PkError *error_code = NULL;
@@ -903,7 +876,7 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	/* we have no updates */
 	if (array->len == 0) {
 		egg_debug ("no updates");
-		gpk_check_update_set_icon_name (cupdate, NULL);
+		gpk_check_update_set_gicon (cupdate, NULL);
 		goto out;
 	}
 
@@ -920,13 +893,13 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	}
 
 	/* work out icon */
-	icon = gpk_check_update_get_best_update_icon (cupdate, array);
+	icon = gpk_check_update_get_status_icon (cupdate, array);
 	if (icon == NULL) {
 		egg_debug ("all updates blocked");
-		gpk_check_update_set_icon_name (cupdate, NULL);
+		gpk_check_update_set_gicon (cupdate, NULL);
 		goto out;
 	}
-	gpk_check_update_set_icon_name (cupdate, icon);
+	gpk_check_update_set_gicon (cupdate, icon);
 
 	/* TRANSLATORS: tooltip: how many updates are waiting to be applied */
 	g_string_append_printf (status_tooltip, ngettext ("There is %d update available",
@@ -1017,6 +990,8 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	/* shouldn't happen */
 	egg_warning ("unknown update mode");
 out:
+	if (icon != NULL)
+		g_object_unref (icon);
 	if (error_code != NULL)
 		g_object_unref (error_code);
 	if (status_tooltip != NULL)
@@ -1095,9 +1070,7 @@ gpk_check_update_query_updates (GpkCheckUpdate *cupdate)
 	}
 
 	/* get new update list */
-	pk_client_get_updates_async (PK_CLIENT(cupdate->priv->task),
-				     pk_bitfield_value (PK_FILTER_ENUM_NONE),
-				     cupdate->priv->cancellable, NULL, NULL,
+	pk_client_get_updates_async (PK_CLIENT(cupdate->priv->task), PK_FILTER_ENUM_NONE, cupdate->priv->cancellable, NULL, NULL,
 				     (GAsyncReadyCallback) gpk_check_update_get_updates_finished_cb, cupdate);
 out:
 	return;
@@ -1126,7 +1099,7 @@ gpk_check_update_updates_changed_cb (PkControl *control, GpkCheckUpdate *cupdate
 	g_return_if_fail (GPK_IS_CHECK_UPDATE (cupdate));
 
 	/* if we don't want to auto check for updates, don't do this either */
-	thresh = gconf_client_get_int (cupdate->priv->gconf_client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
+	thresh = g_settings_get_int (cupdate->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
 	if (thresh == 0) {
 		egg_debug ("not when policy is to never get updates");
 		return;
@@ -1141,6 +1114,10 @@ gpk_check_update_updates_changed_cb (PkControl *control, GpkCheckUpdate *cupdate
 	cupdate->priv->updates_changed_id =
 		g_timeout_add_seconds (GPK_CHECK_UPDATE_UPDATES_CHANGED_TIMEOUT,
 				       (GSourceFunc) gpk_check_update_query_updates_changed_cb, cupdate);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (cupdate->priv->updates_changed_id,
+				 "[GpkCheckUpdate] updates-changed");
+#endif
 }
 
 /**
@@ -1300,9 +1277,9 @@ gpk_check_update_get_distro_upgrades_finished_cb (GObject *object, GAsyncResult
 	}
 
 	/* do we do the notification? */
-	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_DISTRO_UPGRADES, NULL);
+	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_DISTRO_UPGRADES);
 	if (!ret) {
-		egg_debug ("ignoring due to GConf");
+		egg_debug ("ignoring due to GSettings");
 		goto out;
 	}
 
@@ -1435,6 +1412,72 @@ out:
 	return;
 }
 
+/**
+ * gpk_check_update_file_exist_in_root:
+ */
+static gboolean
+gpk_check_update_file_exist_in_root (const gchar *root, const gchar *filename)
+{
+	gboolean ret;
+	GFile *source;
+	gchar *source_path;
+
+	source_path = g_build_filename (root, filename, NULL);
+	source = g_file_new_for_path (source_path);
+
+	/* an interesting file exists */
+	ret = g_file_query_exists (source, NULL);
+	egg_debug ("checking for %s: %s", source_path, ret ? "yes" : "no");
+	if (!ret)
+		goto out;
+out:
+	g_free (source_path);
+	g_object_unref (source);
+	return ret;
+}
+
+/**
+ * gpk_check_update_mount_added_cb:
+ */
+static void
+gpk_check_update_mount_added_cb (GVolumeMonitor *volume_monitor, GMount *mount, GpkCheckUpdate *cupdate)
+{
+	gboolean ret = FALSE;
+	gchar **filenames = NULL;
+	gchar *media_repo_filenames;
+	gchar *root_path;
+	GFile *root;
+	guint i;
+
+	/* check if any installed media is an install disk */
+	root = g_mount_get_root (mount);
+	root_path = g_file_get_path (root);
+
+	/* use settings */
+	media_repo_filenames = g_settings_get_string (cupdate->priv->settings, GPK_SETTINGS_MEDIA_REPO_FILENAMES);
+	if (media_repo_filenames == NULL) {
+		egg_warning ("failed to get media repo filenames");
+		goto out;
+	}
+
+	/* search each possible filename */
+	filenames = g_strsplit (media_repo_filenames, ",", -1);
+	for (i=0; filenames[i] != NULL; i++) {
+		ret = gpk_check_update_file_exist_in_root (root_path, filenames[i]);
+		if (ret)
+			break;
+	}
+
+	/* do an updates check with the new media */
+	if (ret)
+		gpk_check_update_query_updates (cupdate);
+out:
+	g_strfreev (filenames);
+	g_free (media_repo_filenames);
+	g_free (root_path);
+	g_object_unref (root);
+}
+
 /**
  * gpk_check_update_init:
  * @cupdate: This class instance
@@ -1450,16 +1493,12 @@ gpk_check_update_init (GpkCheckUpdate *cupdate)
 	cupdate->priv->updates_changed_id = 0;
 	cupdate->priv->notification_updates_available = NULL;
 	cupdate->priv->notification_error = NULL;
-	cupdate->priv->icon_name = NULL;
+	cupdate->priv->gicon = NULL;
 	cupdate->priv->number_updates_critical_last_shown = 0;
 	cupdate->priv->status_icon = gtk_status_icon_new ();
 	cupdate->priv->cancellable = g_cancellable_new ();
 	cupdate->priv->error_code = NULL;
-
-	/* preload all the common GConf keys */
-	cupdate->priv->gconf_client = gconf_client_get_default ();
-	gconf_client_add_dir (cupdate->priv->gconf_client, GPK_CONF_DIR,
-			      GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	cupdate->priv->settings = g_settings_new (GPK_SETTINGS_SCHEMA);
 
 	cupdate->priv->arefresh = gpk_auto_refresh_new ();
 	g_signal_connect (cupdate->priv->arefresh, "refresh-cache",
@@ -1486,6 +1525,10 @@ gpk_check_update_init (GpkCheckUpdate *cupdate)
 	g_signal_connect (cupdate->priv->dbus_monitor_viewer, "connection-changed",
 			  G_CALLBACK (gpk_cupdate_connection_changed_cb), cupdate);
 
+	/* get a volume monitor so we can watch media */
+	cupdate->priv->volume_monitor = g_volume_monitor_get ();
+	g_signal_connect (cupdate->priv->volume_monitor, "mount-added", G_CALLBACK (gpk_check_update_mount_added_cb), cupdate);
+
 	/* use an asynchronous query object */
 	cupdate->priv->task = PK_TASK (gpk_task_new ());
 	g_object_set (cupdate->priv->task,
@@ -1537,12 +1580,14 @@ gpk_check_update_finalize (GObject *object)
 	g_object_unref (cupdate->priv->status_icon);
 	g_object_unref (cupdate->priv->tlist);
 	g_object_unref (cupdate->priv->arefresh);
-	g_object_unref (cupdate->priv->gconf_client);
+	g_object_unref (cupdate->priv->settings);
 	g_object_unref (cupdate->priv->control);
 	g_object_unref (cupdate->priv->task);
 	g_object_unref (cupdate->priv->dbus_monitor_viewer);
 	g_object_unref (cupdate->priv->cancellable);
-	g_free (cupdate->priv->icon_name);
+	g_object_unref (cupdate->priv->volume_monitor);
+	if (cupdate->priv->gicon != NULL)
+		g_object_unref (cupdate->priv->gicon);
 	if (cupdate->priv->error_code != NULL)
 		g_object_unref (cupdate->priv->error_code);
 	if (cupdate->priv->updates_changed_id > 0)
