@@ -66,10 +66,19 @@ typedef enum {
 
 #if (!PK_CHECK_VERSION(0,6,2))
 #define PK_CLIENT_ERROR_DECLINED_SIMULATION				 PK_CLIENT_ERROR_FAILED
-#define PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED				 PK_ERROR_ENUM_LAST
+#define PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED				 PK_ERROR_ENUM_ENUM_LAST
 #define PK_CLIENT_ERROR_LAST						(PK_CLIENT_ERROR_DECLINED_SIMULATION + 1)
 #endif
 
+#if (!PK_CHECK_VERSION(0,6,3))
+#define PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED			(PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED + 1)
+#endif
+
+#if (!PK_CHECK_VERSION(0,6,4))
+#define PK_MESSAGE_ENUM_OTHER_UPDATES_HELD_BACK				(PK_MESSAGE_ENUM_REPO_FOR_DEVELOPERS_ONLY + 1)
+#define PK_ERROR_ENUM_INSTALL_ROOT_INVALID				(PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED + 1)
+#endif
+
 void		 gpk_enum_test				(gpointer	 data);
 const gchar	*gpk_role_enum_to_localised_past	(PkRoleEnum	 role)
 							 G_GNUC_CONST;
