@@ -34,7 +34,6 @@
 #endif /* HAVE_UNISTD_H */
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 #include <libnotify/notify.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
@@ -59,7 +58,7 @@ static void     gpk_hardware_finalize	(GObject	  *object);
 struct GpkHardwarePrivate
 {
 	PkTask			*task;
-	GConfClient		*gconf_client;
+	GSettings		*settings;
 	DBusGConnection		*connection;
 	DBusGProxy		*proxy;
 	gchar			**package_ids;
@@ -113,8 +112,8 @@ gpk_hardware_libnotify_cb (NotifyNotification *notification, gchar *action, gpoi
 		pk_client_install_packages_async (PK_CLIENT(hardware->priv->task), TRUE, hardware->priv->package_ids, NULL, NULL, NULL,
 						  (GAsyncReadyCallback) gpk_hardware_install_packages_cb, hardware);
 	} else if (g_strcmp0 (action, GPK_HARDWARE_DONT_PROMPT_ACTION) == 0) {
-		egg_debug ("set %s to FALSE", GPK_CONF_ENABLE_CHECK_HARDWARE);
-		gconf_client_set_bool (hardware->priv->gconf_client, GPK_CONF_ENABLE_CHECK_HARDWARE, FALSE, NULL);
+		egg_debug ("set %s to FALSE", GPK_SETTINGS_ENABLE_CHECK_HARDWARE);
+		g_settings_set_boolean (hardware->priv->settings, GPK_SETTINGS_ENABLE_CHECK_HARDWARE, FALSE);
 	} else {
 		egg_warning ("unknown action id: %s", action);
 	}
@@ -243,14 +242,19 @@ gpk_hardware_device_added_timeout (gpointer data)
 static void
 gpk_hardware_device_added_cb (DBusGProxy *proxy, const gchar *udi, GpkHardware *hardware)
 {
+	guint added_id;
+
 	egg_debug ("hardware added. udi=%s", udi);
 	/* we get multiple hal signals for one device plugin. Ignore all but first one.
 	   TODO: should we act on a different one ?
 	*/
 	if (hardware->priv->udi == NULL) {
 		hardware->priv->udi = g_strdup (udi);
-		g_timeout_add_seconds (GPK_HARDWARE_MULTIPLE_HAL_SIGNALS_DELAY,
+		added_id = g_timeout_add_seconds (GPK_HARDWARE_MULTIPLE_HAL_SIGNALS_DELAY,
 				       gpk_hardware_device_added_timeout, hardware);
+#if GLIB_CHECK_VERSION(2,25,8)
+		g_source_set_name_by_id (added_id, "[GpkHardware] added");
+#endif
 	}
 }
 
@@ -275,17 +279,18 @@ static void
 gpk_hardware_init (GpkHardware *hardware)
 {
 	gboolean ret;
+	guint login_id = 0;
 	GError *error = NULL;
 
 	hardware->priv = GPK_HARDWARE_GET_PRIVATE (hardware);
-	hardware->priv->gconf_client = gconf_client_get_default ();
+	hardware->priv->settings = g_settings_new (GPK_SETTINGS_SCHEMA);
 	hardware->priv->package_ids = NULL;
 	hardware->priv->udi = NULL;
 
 	/* should we check and show the user */
-	ret = gconf_client_get_bool (hardware->priv->gconf_client, GPK_CONF_ENABLE_CHECK_HARDWARE, NULL);
+	ret = g_settings_get_boolean (hardware->priv->settings, GPK_SETTINGS_ENABLE_CHECK_HARDWARE);
 	if (!ret) {
-		egg_debug ("hardware driver checking disabled in GConf");
+		egg_debug ("hardware driver checking disabled in GSettings");
 		return;
 	}
 	hardware->priv->task = PK_TASK(gpk_task_new ());
@@ -309,7 +314,10 @@ gpk_hardware_init (GpkHardware *hardware)
 				     G_CALLBACK (gpk_hardware_device_added_cb), hardware, NULL);
 
 	/* check at startup (plus delay) and see if there is cold plugged hardware needing drivers */
-	g_timeout_add_seconds (GPK_HARDWARE_LOGIN_DELAY, gpk_hardware_timeout_cb, hardware);
+	login_id = g_timeout_add_seconds (GPK_HARDWARE_LOGIN_DELAY, gpk_hardware_timeout_cb, hardware);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (login_id, "[GpkHardware] login");
+#endif
 }
 
 /**
@@ -338,7 +346,7 @@ gpk_hardware_finalize (GObject *object)
 	hardware = GPK_HARDWARE (object);
 
 	g_return_if_fail (hardware->priv != NULL);
-	g_object_unref (hardware->priv->gconf_client);
+	g_object_unref (hardware->priv->settings);
 	g_object_unref (PK_CLIENT(hardware->priv->task));
 	g_strfreev (hardware->priv->package_ids);
 
