@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -25,7 +25,6 @@
 #include <locale.h>
 
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 #include <packagekit-glib2/packagekit.h>
 #include <unique/unique.h>
 
@@ -41,8 +40,7 @@ static GtkBuilder *builder = NULL;
 static GtkListStore *list_store = NULL;
 static PkClient *client = NULL;
 static PkBitfield roles;
-static GConfClient *gconf_client;
-static gboolean show_details;
+static GSettings *settings;
 static GtkTreePath *path_global = NULL;
 static GtkWidget *image_animation = NULL;
 static guint status_id = 0;
@@ -213,10 +211,38 @@ gpk_repo_progress_cb (PkProgress *progress, PkProgressType type, gpointer user_d
 
 	/* only show after some time in the transaction */
 	status_id = g_timeout_add (GPK_UI_STATUS_SHOW_DELAY, (GSourceFunc) gpk_repo_status_changed_timeout_cb, progress);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (status_id, "[GpkRepo] status");
+#endif
 out:
 	return;
 }
 
+/**
+ * gpk_repo_process_messages_cb:
+ **/
+static void
+gpk_repo_process_messages_cb (PkMessage *item, gpointer user_data)
+{
+	GtkWindow *window;
+	PkMessageEnum type;
+	gchar *details;
+	const gchar *title;
+
+	/* get data */
+	g_object_get (item,
+		      "type", &type,
+		      "details", &details,
+		      NULL);
+
+	/* show a modal window */
+	window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_repo"));
+	title = gpk_message_enum_to_localised_text (type);
+	gpk_error_dialog_modal (window, title, details, NULL);
+
+	g_free (details);
+}
+
 /**
  * gpk_repo_repo_enable_cb
  **/
@@ -228,6 +254,7 @@ gpk_repo_repo_enable_cb (GObject *object, GAsyncResult *res, gpointer user_data)
 	PkResults *results = NULL;
 	PkError *error_code = NULL;
 	GtkWindow *window;
+	GPtrArray *array;
 
 	/* get the results */
 	results = pk_client_generic_finish (client, res, &error);
@@ -247,6 +274,11 @@ gpk_repo_repo_enable_cb (GObject *object, GAsyncResult *res, gpointer user_data)
 					gpk_error_enum_to_localised_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 		goto out;
 	}
+
+	/* process messages */
+	array = pk_results_get_message_array (results);
+	g_ptr_array_foreach (array, (GFunc) gpk_repo_process_messages_cb, NULL);
+	g_ptr_array_unref (array);
 out:
 	if (error_code != NULL)
 		g_object_unref (error_code);
@@ -431,8 +463,10 @@ static void
 gpk_repo_repo_list_refresh (void)
 {
 	PkBitfield filters;
+	GtkWidget *widget;
 	GtkTreeView *treeview;
 	GtkTreeModel *model;
+	gboolean show_details;
 
 	/* mark the items as not used */
 	treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, "treeview_repo"));
@@ -440,6 +474,8 @@ gpk_repo_repo_list_refresh (void)
 	gpk_repo_mark_nonactive (model);
 
 	egg_debug ("refreshing list");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_detail"));
+	show_details = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 	if (!show_details)
 		filters = pk_bitfield_value (PK_FILTER_ENUM_NOT_DEVELOPMENT);
 	else
@@ -459,14 +495,11 @@ gpk_repo_repo_list_changed_cb (PkControl *control, gpointer data)
 }
 
 /**
- * gpk_repo_checkbutton_details:
+ * gpk_repo_checkbutton_detail_cb:
  **/
 static void
-gpk_repo_checkbutton_details (GtkWidget *widget, gpointer data)
+gpk_repo_checkbutton_detail_cb (GtkWidget *widget, gpointer data)
 {
-	show_details = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	egg_debug ("Changing %s to %i", GPK_CONF_REPO_SHOW_DETAILS, show_details);
-	gconf_client_set_bool (gconf_client, GPK_CONF_REPO_SHOW_DETAILS, show_details, NULL);
 	gpk_repo_repo_list_refresh ();
 }
 
@@ -622,7 +655,7 @@ main (int argc, char *argv[])
 	g_signal_connect (unique_app, "message-received",
 			  G_CALLBACK (gpk_repo_message_received_cb), NULL);
 
-	gconf_client = gconf_client_get_default ();
+	settings = g_settings_new (GPK_SETTINGS_SCHEMA);
 
 	loop = g_main_loop_new (NULL, FALSE);
 
@@ -663,10 +696,12 @@ main (int argc, char *argv[])
 			  G_CALLBACK (gpk_button_help_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_detail"));
-	show_details = gconf_client_get_bool (gconf_client, GPK_CONF_REPO_SHOW_DETAILS, NULL);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), show_details);
+	g_settings_bind (settings,
+			 GPK_SETTINGS_REPO_SHOW_DETAILS,
+			 widget, "active",
+			 G_SETTINGS_BIND_DEFAULT);
 	g_signal_connect (widget, "clicked",
-			  G_CALLBACK (gpk_repo_checkbutton_details), NULL);
+			  G_CALLBACK (gpk_repo_checkbutton_detail_cb), NULL);
 
 	/* set a size, if the screen allows */
 	gpk_window_set_size_request (GTK_WINDOW (main_window), 500, 300);
@@ -710,7 +745,7 @@ main (int argc, char *argv[])
 	g_object_unref (list_store);
 out_build:
 	g_object_unref (builder);
-	g_object_unref (gconf_client);
+	g_object_unref (settings);
 	g_object_unref (control);
 	g_object_unref (client);
 	g_main_loop_unref (loop);
